#include "gaussian_pdfcdf.h"
#include <cmath>
#include <gsl/gsl_cdf.h>

#define sqrt2pi 2.5066282746310005024

//// ============================================  Guassian PDF
void gaussian_pdf (
   double *pdf,
   const double *x,
   int numel_x,
   double mean,
   double sigma
   ) {
   
   // Coumputational variables
   double sigma_factor = 1.0/(sqrt2pi * sigma);
   double two_sigma_sq = 2.0*sigma*sigma;
   double z;
   
   // Cycle variable
   int ii = 0;
   
   for ( ii=0; ii<numel_x; ++ii ) {
      z = x[ii]-mean;
      pdf[ii] = sigma_factor
         * exp ( -z*z/two_sigma_sq );
      }

}

//// ============================================  Guassian CDF
void gaussian_cdf (
   double *cdf,
   const double *x,
   int numel_x,
   double mean,
   double sigma
   ) {
   
   // Coumputational variables
   double z;
   
   // Cycle variable
   int ii = 0;
   
   for ( ii=0; ii<numel_x; ++ii ) {
      z = x[ii]-mean;
      cdf[ii] = gsl_cdf_gaussian_P( z, sigma);
      }

}